@@ -100,6 +100,12 @@ class Act():
                 print 'request for %s resulted in a status code of %s' % (uwsgi_uri, h.status_code)
                 print 'the entire header follows:'
                 print h
+                if h.status_code == 500:
+                    s = 'A status code of 500 means that the port is bound OK but that '
+                    s+= 'there is probably a coding error somewhere in the Act '
+                    s+= 'which is causing it to fail to load. '
+                    s+= 'In your browser - and with DEBUG enabled, visit %s and review the error message' % (uwsgi_uri)
+                    print s
                 self.uwsgi_ip = None
                 self.uwsgi_port = None
         except:
