@@ -10,7 +10,7 @@ def portsniffer(log_file):
         return None
     try:
         fo = open(log_file, 'r')
-    except IOError:
+    except:
         print 'Could not open log file: %s' % log_file
         return None, None
 
